pub fn replay_atlas_commands(
commands: &mut Vec<AtlasCommand>,
target: &mut impl DrawSink,
)Expand description
Replay recorded atlas commands into a DrawSink.
The commands Vec is drained, freeing memory as each command is consumed.
pub fn replay_atlas_commands(
commands: &mut Vec<AtlasCommand>,
target: &mut impl DrawSink,
)Replay recorded atlas commands into a DrawSink.
The commands Vec is drained, freeing memory as each command is consumed.