stroke_glyph

Function stroke_glyph 

pub(crate) fn stroke_glyph(
    renderer: &mut impl GlyphRenderer,
    prepared_glyph: PreparedGlyph<'_>,
    atlas_cacher: &mut AtlasCacher<'_>,
    outline_cache: &mut OutlineCacheSession<'_>,
)
Stroke a prepared glyph, using the glyph atlas when possible and falling back to direct rendering otherwise.