pub(crate) fn supports_atlas_caching(
transform: &Affine,
glyph_type: CachedGlyphType,
) -> boolExpand description
Returns true if the transform is safe for atlas-cached glyph rendering.
pub(crate) fn supports_atlas_caching(
transform: &Affine,
glyph_type: CachedGlyphType,
) -> boolReturns true if the transform is safe for atlas-cached glyph rendering.